@@ -1,12 +1,12 @@
 package WebService::Toggl::API::Clients;
 
 use Moo;
-with 'WebService::Toggl::API', 'WebService::Toggl::Role::Set';
+with 'WebService::Toggl::Role::API', 'WebService::Toggl::Role::Set';
 use namespace::clean;
 
 sub list_of { '::Client' }
 
-sub my_url { '/clients' }
+sub api_path { 'clients' }
 
 
 1;
