@@ -1,12 +1,12 @@
 package WebService::Toggl::API::TimeEntries;
 
 use Moo;
-with 'WebService::Toggl::API', 'WebService::Toggl::Role::Set';
+with 'WebService::Toggl::Role::API', 'WebService::Toggl::Role::Set';
 use namespace::clean;
 
 sub list_of { '::TimeEntry' }
 
-sub my_url { '/time_entries' }
+sub api_path { 'time_entries' }
 
 1;
 __END__
